==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBFluent<A extends LoadBalancerSettingsConsistentHashLBFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBFluent() {
  }
  public LoadBalancerSettingsConsistentHashLBFluent(LoadBalancerSettingsConsistentHashLB instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLB());

    if (instance != null) {
      this.withHashKey(instance.getHashKey());
      this.withMinimumRingSize(instance.getMinimumRingSize());
      this.withHashKey(instance.getHashKey());
      this.withMinimumRingSize(instance.getMinimumRingSize());
    }
  }
  private VisitableBuilder<? extends IsLoadBalancerSettingsConsistentHashLBHashKey,?> hashKey;
  private Integer minimumRingSize;
  public IsLoadBalancerSettingsConsistentHashLBHashKey buildHashKey() {
    return this.hashKey!=null?this.hashKey.build():null;
  }
  public A withHashKey(IsLoadBalancerSettingsConsistentHashLBHashKey hashKey) {
    if (hashKey==null){ this.hashKey = null; _visitables.remove("hashKey"); return (A) this;}
    VisitableBuilder<? extends IsLoadBalancerSettingsConsistentHashLBHashKey,?> builder = builder(hashKey); _visitables.get("hashKey").clear();_visitables.get("hashKey").add(builder);this.hashKey = builder;
    return (A) this;
  }
  public boolean hasHashKey() {
    return this.hashKey != null;
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKey() {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested(null);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKeyLike(LoadBalancerSettingsConsistentHashLBHttpCookie item) {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested(item);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey() {
    return new LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested(null);
  }
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpHeaderName item) {
    return new LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested(item);
  }
  public A withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey(String httpHeaderName) {
    return (A)withHashKey(new LoadBalancerSettingsConsistentHashLBHttpHeaderName(httpHeaderName));
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey() {
    return new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested(null);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName item) {
    return new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested(item);
  }
  public A withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey(String httpQueryParameterName) {
    return (A)withHashKey(new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(httpQueryParameterName));
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey() {
    return new LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested(null);
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKeyLike(LoadBalancerSettingsConsistentHashLBUseSourceIp item) {
    return new LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested(item);
  }
  public A withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey(Boolean useSourceIp) {
    return (A)withHashKey(new LoadBalancerSettingsConsistentHashLBUseSourceIp(useSourceIp));
  }
  public Integer getMinimumRingSize() {
    return this.minimumRingSize;
  }
  public A withMinimumRingSize(Integer minimumRingSize) {
    this.minimumRingSize=minimumRingSize; return (A) this;
  }
  public boolean hasMinimumRingSize() {
    return this.minimumRingSize != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBFluent that = (LoadBalancerSettingsConsistentHashLBFluent) o;
    if (!java.util.Objects.equals(hashKey, that.hashKey)) return false;

    if (!java.util.Objects.equals(minimumRingSize, that.minimumRingSize)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hashKey,  minimumRingSize,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hashKey != null) { sb.append("hashKey:"); sb.append(hashKey + ","); }
    if (minimumRingSize != null) { sb.append("minimumRingSize:"); sb.append(minimumRingSize); }
    sb.append("}");
    return sb.toString();
  }
  protected static <T>VisitableBuilder<T,?> builder(Object item) {
    switch (item.getClass().getName()) {
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBHttpCookie": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBHttpCookieBuilder((LoadBalancerSettingsConsistentHashLBHttpCookie) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBHttpHeaderName": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder((LoadBalancerSettingsConsistentHashLBHttpHeaderName) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBHttpQueryParameterName": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder((LoadBalancerSettingsConsistentHashLBHttpQueryParameterName) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBUseSourceIp": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder((LoadBalancerSettingsConsistentHashLBUseSourceIp) item);
    }
 return (VisitableBuilder<T, ?>)builderOf(item);
  }
  public class LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N> extends LoadBalancerSettingsConsistentHashLBHttpCookieFluent<LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested(LoadBalancerSettingsConsistentHashLBHttpCookie item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBHttpCookieBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    public N endLoadBalancerSettingsConsistentHashLBHttpCookieKey() {
      return and();
    }
    
  }
  public class LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N> extends LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested(LoadBalancerSettingsConsistentHashLBHttpHeaderName item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    public N endLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey() {
      return and();
    }
    
  }
  public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N> extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    public N endLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey() {
      return and();
    }
    
  }
  public class LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N> extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested(LoadBalancerSettingsConsistentHashLBUseSourceIp item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    public N endLoadBalancerSettingsConsistentHashLBUseSourceIpKey() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsConsistentHashLBFluent<A extends LoadBalancerSettingsConsistentHashLBFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBFluent() {
  }
  
  public LoadBalancerSettingsConsistentHashLBFluent(LoadBalancerSettingsConsistentHashLB instance) {
    this.copyInstance(instance);
  }
  private VisitableBuilder<? extends IsLoadBalancerSettingsConsistentHashLBHashKey,?> hashKey;
  private Integer minimumRingSize;
  
  protected void copyInstance(LoadBalancerSettingsConsistentHashLB instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLB());
  
    if (instance != null) {
        this.withHashKey(instance.getHashKey());
        this.withMinimumRingSize(instance.getMinimumRingSize());
        this.withHashKey(instance.getHashKey());
        this.withMinimumRingSize(instance.getMinimumRingSize());
      }
  }
  
  public IsLoadBalancerSettingsConsistentHashLBHashKey buildHashKey() {
    return this.hashKey!=null?this.hashKey.build():null;
  }
  
  public A withHashKey(IsLoadBalancerSettingsConsistentHashLBHashKey hashKey) {
    if (hashKey==null){ this.hashKey = null; _visitables.remove("hashKey"); return (A) this;}
    VisitableBuilder<? extends IsLoadBalancerSettingsConsistentHashLBHashKey,?> builder = builder(hashKey); _visitables.get("hashKey").clear();_visitables.get("hashKey").add(builder);this.hashKey = builder;
    return (A) this;
  }
  
  public boolean hasHashKey() {
    return this.hashKey != null;
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKey() {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested(null);
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpCookieKeyLike(LoadBalancerSettingsConsistentHashLBHttpCookie item) {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested(item);
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey() {
    return new LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested(null);
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpHeaderName item) {
    return new LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested(item);
  }
  
  public A withNewLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey(String httpHeaderName) {
    return (A)withHashKey(new LoadBalancerSettingsConsistentHashLBHttpHeaderName(httpHeaderName));
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey() {
    return new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested(null);
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyLike(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName item) {
    return new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested(item);
  }
  
  public A withNewLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey(String httpQueryParameterName) {
    return (A)withHashKey(new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(httpQueryParameterName));
  }
  
  public LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey() {
    return new LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested(null);
  }
  
  public LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<A> withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKeyLike(LoadBalancerSettingsConsistentHashLBUseSourceIp item) {
    return new LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested(item);
  }
  
  public A withNewLoadBalancerSettingsConsistentHashLBUseSourceIpKey(Boolean useSourceIp) {
    return (A)withHashKey(new LoadBalancerSettingsConsistentHashLBUseSourceIp(useSourceIp));
  }
  
  public Integer getMinimumRingSize() {
    return this.minimumRingSize;
  }
  
  public A withMinimumRingSize(Integer minimumRingSize) {
    this.minimumRingSize=minimumRingSize; return (A) this;
  }
  
  public boolean hasMinimumRingSize() {
    return this.minimumRingSize != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBFluent that = (LoadBalancerSettingsConsistentHashLBFluent) o;
    if (!java.util.Objects.equals(hashKey, that.hashKey)) return false;
  
    if (!java.util.Objects.equals(minimumRingSize, that.minimumRingSize)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(hashKey,  minimumRingSize,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hashKey != null) { sb.append("hashKey:"); sb.append(hashKey + ","); }
    if (minimumRingSize != null) { sb.append("minimumRingSize:"); sb.append(minimumRingSize); }
    sb.append("}");
    return sb.toString();
  }
  
  protected static <T>VisitableBuilder<T,?> builder(Object item) {
    switch (item.getClass().getName()) {
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBHttpCookie": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBHttpCookieBuilder((LoadBalancerSettingsConsistentHashLBHttpCookie) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBHttpHeaderName": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder((LoadBalancerSettingsConsistentHashLBHttpHeaderName) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBHttpQueryParameterName": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder((LoadBalancerSettingsConsistentHashLBHttpQueryParameterName) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHashLBUseSourceIp": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder((LoadBalancerSettingsConsistentHashLBUseSourceIp) item);
    }
   return (VisitableBuilder<T, ?>)builderOf(item);
  }
  public class LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N> extends LoadBalancerSettingsConsistentHashLBHttpCookieFluent<LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBHttpCookieKeyNested(LoadBalancerSettingsConsistentHashLBHttpCookie item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBHttpCookieBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    
    public N endLoadBalancerSettingsConsistentHashLBHttpCookieKey() {
      return and();
    }
    
  
  }
  public class LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N> extends LoadBalancerSettingsConsistentHashLBHttpHeaderNameFluent<LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBHttpHeaderNameKeyNested(LoadBalancerSettingsConsistentHashLBHttpHeaderName item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBHttpHeaderNameBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    
    public N endLoadBalancerSettingsConsistentHashLBHttpHeaderNameKey() {
      return and();
    }
    
  
  }
  public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N> extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKeyNested(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    
    public N endLoadBalancerSettingsConsistentHashLBHttpQueryParameterNameKey() {
      return and();
    }
    
  
  }
  public class LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N> extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLBUseSourceIpKeyNested(LoadBalancerSettingsConsistentHashLBUseSourceIp item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashLBUseSourceIpBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBFluent.this.withHashKey(builder.build());
    }
    
    public N endLoadBalancerSettingsConsistentHashLBUseSourceIpKey() {
      return and();
    }
    
  
  }

}
